@@ -40,7 +40,8 @@ class BaseObject(dict):
         self[self._pk] = id
     
     def __setattr__(self, k, v):
-        if k[0] == '_' or k in self.__dict__ or hasattr(type(self), k):
+        if k[0] == '_' or k in self.__dict__ or (hasattr(type(self), k) and not hasattr(getattr(type(self), k), '__call__') ):
+            
             return super(BaseObject, self).__setattr__(k, v)
         else:
             self[k] = v
